@@ -15,8 +15,8 @@ import (
 	"k8s.io/client-go/kubernetes"
 	"k8s.io/client-go/rest"
 	"k8s.io/client-go/restmapper"
-	"k8s.io/kubernetes/cmd/controller-manager/app"
-	"k8s.io/kubernetes/pkg/controller"
+	"k8s.io/controller-manager/app"
+	"k8s.io/controller-manager/pkg/clientbuilder"
 
 	openshiftcontrolplanev1 "github.com/openshift/api/openshiftcontrolplane/v1"
 	appsclient "github.com/openshift/client-go/apps/clientset/versioned"
@@ -108,7 +108,7 @@ func NewControllerContext(
 		OpenshiftControllerConfig: config,
 
 		ClientBuilder: OpenshiftControllerClientBuilder{
-			ControllerClientBuilder: controller.SAControllerClientBuilder{
+			ControllerClientBuilder: clientbuilder.SAControllerClientBuilder{
 				ClientConfig:         rest.AnonymousClientConfig(clientConfig),
 				CoreClient:           kubeClient.CoreV1(),
 				AuthenticationClient: kubeClient.AuthenticationV1(),
@@ -116,7 +116,7 @@ func NewControllerContext(
 			},
 		},
 		HighRateLimitClientBuilder: OpenshiftControllerClientBuilder{
-			ControllerClientBuilder: controller.SAControllerClientBuilder{
+			ControllerClientBuilder: clientbuilder.SAControllerClientBuilder{
 				ClientConfig:         rest.AnonymousClientConfig(highRateLimitClientConfig),
 				CoreClient:           kubeClient.CoreV1(),
 				AuthenticationClient: kubeClient.AuthenticationV1(),
@@ -229,7 +229,7 @@ func (c *ControllerContext) IsControllerEnabled(name string) bool {
 }
 
 type ControllerClientBuilder interface {
-	controller.ControllerClientBuilder
+	clientbuilder.ControllerClientBuilder
 
 	OpenshiftAppsClient(name string) (appsclient.Interface, error)
 	OpenshiftAppsClientOrDie(name string) appsclient.Interface
@@ -260,7 +260,7 @@ type ControllerClientBuilder interface {
 type InitFunc func(ctx *ControllerContext) (bool, error)
 
 type OpenshiftControllerClientBuilder struct {
-	controller.ControllerClientBuilder
+	clientbuilder.ControllerClientBuilder
 }
 
 func (b OpenshiftControllerClientBuilder) OpenshiftOperatorClient(name string) (operatorclient.Interface, error) {
